@@ -240,14 +240,14 @@ def extractpoints_from2D_build3Dobj(input_folder, output_name, downsample_rate=1
     array_saveto_pcd(loc, color, output_name)
 
 
-def set_foler_location(set_2dimg_folder, set_3dobj_folder):
+def set_folder_location(set_2dimg_folder, set_3dobj_folder):
     global OUTPUT_FOLDER_2DIMG
     global OUTPUT_FOLDER_3DIMG
     OUTPUT_FOLDER_2DIMG = set_2dimg_folder
     OUTPUT_FOLDER_3DIMG = set_3dobj_folder
 
 
-def display_foler_location():
+def display_folder_location():
     print('2D image folder location:', OUTPUT_FOLDER_2DIMG)
     print('3D object folder location:', OUTPUT_FOLDER_3DIMG)
 
